@@ -27,8 +27,9 @@ class ZonesImportTest(BaseZonesImportTest):
     @classmethod
     def setup_clients(cls):
         super(ZonesImportTest, cls).setup_clients()
-        cls.client = cls.os.zone_imports_client
-        cls.zones_client = cls.os.zones_client
+
+        cls.client = cls.os_primary.dns_v2.ZoneImportsClient()
+        cls.zones_client = cls.os_primary.dns_v2.ZonesClient()
 
     @decorators.attr(type='slow')
     @decorators.idempotent_id('679f38d0-2f2f-49c5-934e-8fe0c452f56e')
@@ -46,6 +47,10 @@ class ZonesImportTest(BaseZonesImportTest):
 
         LOG.info('Check the zone import looks good')
         _, zone_import = self.client.show_zone_import(zone_import['id'])
+        self.addCleanup(self.wait_zone_delete,
+                        self.zones_client,
+                        zone_import['zone_id'])
+
         self.assertEqual('COMPLETE', zone_import['status'])
         self.assertIsNotNone(zone_import['zone_id'])
         self.assertIsNotNone(zone_import['links'].get('zone'))
